@@ -44,15 +44,16 @@ sub set_code          { $_[0]->{Code} = $_[1];          }
 sub set_identifier    { $_[0]->{Identifier} = $_[1];    }
 sub set_authenticator { $_[0]->{Authenticator} = $_[1]; }
 
-sub attributes { keys %{$_[0]->{Attributes}};        }
-sub attr     { $_[0]->{Attributes}->{$_[1]};         }
-sub set_attr { $_[0]->{Attributes}->{$_[1]} = $_[2]; }
-sub unset_attr { delete $_[0]->{Attributes}->{$_[1]}; }
+sub attributes { keys %{$_[0]->{Attributes}};		}
+sub attr     { $_[0]->{Attributes}->{lc $_[1]};		}
+sub set_attr { $_[0]->{Attributes}->{lc $_[1]} = $_[2];	}
+sub unset_attr { delete $_[0]->{Attributes}->{lc $_[1]} }
 
-sub vendors      { keys %{$_[0]->{VSAttributes}};                          }
-sub vsattributes { keys %{$_[0]->{VSAttributes}->{$_[1]}};                 }
-sub vsattr       { $_[0]->{VSAttributes}->{$_[1]}->{$_[2]};                }
-sub set_vsattr   { push @{$_[0]->{VSAttributes}->{$_[1]}->{$_[2]}}, $_[3]; }
+sub vendors      { keys %{$_[0]->{VSAttributes}};			}
+sub vsattributes { keys %{$_[0]->{VSAttributes}->{lc $_[1]}};           }
+sub vsattr       { $_[0]->{VSAttributes}->{lc $_[1]}->{lc $_[2]};       }
+sub set_vsattr   { push @{$_[0]->{VSAttributes}->{lc $_[1]}->{lc $_[2]}}, 
+		   $_[3]; }
 
 sub show_unknown_entries { $_[0]->{unknown_entries} = $_[1]; }
 
